# C and C++ rule generation for interfaces.

# Generate exported interfaces.

include $(IDL_MK_DIR)/export_interface_c.mk
include $(IDL_MK_DIR)/export_interface_cc.mk
include $(IDL_MK_DIR)/export_comp_interface_c.mk
include $(IDL_MK_DIR)/export_comp_interface_cc.mk

# Generate routines.

include $(IDL_MK_DIR)/client_interface_c.mk
include $(IDL_MK_DIR)/client_interface_cc.mk
include $(IDL_MK_DIR)/server_interface_c.mk
include $(IDL_MK_DIR)/server_interface_cc.mk
include $(IDL_MK_DIR)/comp_interface_c.mk
include $(IDL_MK_DIR)/comp_interface_cc.mk

# Extra rules to generate files from the interface descriptions.

# Generate an interface rule for each individual client interface.

$(foreach INTERFACE,$(CLIENT_INTERFACES_C),\
$(eval $(call client_interface_c_template,$(INTERFACE))))

$(foreach INTERFACE,$(CLIENT_INTERFACES_CC),\
$(eval $(call client_interface_cc_template,$(INTERFACE))))

# Generate an interface rule for each individual server interface.

$(foreach INTERFACE,$(SERVER_INTERFACES_C),\
$(eval $(call server_interface_c_template,$(INTERFACE))))

$(foreach INTERFACE,$(SERVER_INTERFACES_CC),\
$(eval $(call server_interface_cc_template,$(INTERFACE))))

# Generate a compound interface rule for each compound interface, using details
# provided in the <interface>_NAME and <interface>_INTERFACES definitions.

$(foreach INTERFACE,$(COMP_INTERFACES_C),\
$(eval $(call comp_interface_c_template,$(INTERFACE),$(value $(INTERFACE)_NAME),$(value $(INTERFACE)_INTERFACES))))

$(foreach INTERFACE,$(COMP_INTERFACES_CC),\
$(eval $(call comp_interface_cc_template,$(INTERFACE),$(value $(INTERFACE)_NAME),$(value $(INTERFACE)_INTERFACES))))

# Generate rules for exported individual interfaces.

$(foreach INTERFACE,$(sort $(CLIENT_INTERFACES_C) $(SERVER_INTERFACES_C)),\
$(eval $(call export_interface_c_template,$(INTERFACE))))

$(foreach INTERFACE,$(sort $(CLIENT_INTERFACES_CC) $(SERVER_INTERFACES_CC)),\
$(eval $(call export_interface_cc_template,$(INTERFACE))))

# Generate rules for exported compound interfaces.

$(foreach INTERFACE,$(COMP_INTERFACES_C),\
$(eval $(call export_comp_interface_c_template,$(INTERFACE),$(value $(INTERFACE)_NAME),$(value $(INTERFACE)_INTERFACES))))

$(foreach INTERFACE,$(COMP_INTERFACES_CC),\
$(eval $(call export_comp_interface_cc_template,$(INTERFACE),$(value $(INTERFACE)_NAME),$(value $(INTERFACE)_INTERFACES))))
